
# This file is automatically generated during the generation of setup.py
# Copyright 2023-2026, Open XAI PnP
author = "Team SAIL"
author_email = "open.xai@gmail.com"
version = "0.1.1"
full_version = "0.1.1"
git_version = '80f0228e8971a8bfe5b3c022430a7bf06177f74e'
release = True
homepage = "https://github.com/OpenXAIProject/pnpxai"
